@@ -33,6 +33,7 @@
 #  define BALOO_WIDGETS_DECL_DEPRECATED_NO_EXPORT BALOO_WIDGETS_NO_EXPORT BALOO_WIDGETS_DECL_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef BALOO_WIDGETS_NO_DEPRECATED
 #    define BALOO_WIDGETS_NO_DEPRECATED
@@ -61,7 +62,7 @@
 #define BALOO_WIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BALOO_WIDGETS_NO_DEPRECATED
-#  define BALOO_WIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x180502
+#  define BALOO_WIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x180b50
 #endif
 #ifdef BALOO_WIDGETS_NO_DEPRECATED_WARNINGS
 #  define BALOO_WIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -71,7 +72,7 @@
 #  ifdef BALOO_WIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BALOO_WIDGETS_DEPRECATED_WARNINGS_SINCE BALOO_WIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BALOO_WIDGETS_DEPRECATED_WARNINGS_SINCE 0x180502
+#    define BALOO_WIDGETS_DEPRECATED_WARNINGS_SINCE 0x180b50
 #  endif
 #endif
 
